Package: latticeExtra
Version: 0.6-30
Date: 2022-06-30
Title: Extra Graphical Utilities Based on Lattice
Author: Deepayan Sarkar <deepayan.sarkar@r-project.org>, Felix Andrews <felix@nfrac.org>
Maintainer: Deepayan Sarkar <deepayan.sarkar@r-project.org>
Description: Building on the infrastructure provided by the lattice
	     package, this package provides several new high-level
	     functions and methods, as well as additional utilities
	     such as panel and axis annotation functions.
Depends: R (>= 3.6.0), lattice
Imports: grid, stats, utils, grDevices, png, jpeg, RColorBrewer,
        interp, MASS
Suggests: maps, mapproj, deldir, quantreg, zoo, mgcv
URL: http://latticeextra.r-forge.r-project.org/
LazyLoad: yes
LazyData: yes
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2022-06-30 07:04:00 UTC; deepayan
Repository: CRAN
Date/Publication: 2022-07-04 16:50:02 UTC
Built: R 4.4.0; ; 2026-05-12 12:14:04 UTC; unix
