Package: latticeExtra
Version: 0.6-31
Date: 2025-09-08
Title: Extra Graphical Utilities Based on Lattice
Authors@R: c(person("Deepayan", "Sarkar", role = c("aut", "cre"),
	            email = "deepayan.sarkar@r-project.org",
		    comment = c(ORCID = "0000-0003-4107-1553")),
              person("Felix", "Andrews", role = "aut", email = "felix@nfrac.org"))
Author: Deepayan Sarkar [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4107-1553>),
  Felix Andrews [aut]
Maintainer: Deepayan Sarkar <deepayan.sarkar@r-project.org>
Description: Building on the infrastructure provided by the lattice
	     package, this package provides several new high-level
	     functions and methods, as well as additional utilities
	     such as panel and axis annotation functions.
Depends: R (>= 3.6.0), lattice
Imports: grid, stats, utils, grDevices, png, jpeg, RColorBrewer,
        interp, MASS
Suggests: maps, mapproj, deldir, quantreg, zoo, mgcv
URL: http://latticeextra.r-forge.r-project.org/
BugReports: https://github.com/deepayan/latticeExtra/issues
LazyLoad: yes
LazyData: yes
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2025-09-09 05:30:05 UTC; deepayan
Repository: CRAN
Date/Publication: 2025-09-10 06:40:45 UTC
Built: R 4.6.0; ; 2026-04-27 06:06:32 UTC; unix
