

import(grid)
import(lattice)

import(stats)
import(grDevices)

importFrom(utils, modifyList, head, tail, download.file)
importFrom(RColorBrewer, brewer.pal)
importFrom(png, readPNG)
importFrom(jpeg, readJPEG)
importFrom(interp, voronoi.polygons, voronoi.mosaic)



export(dendrogramGrob) ## FIXME: add some variant of heatmap

export(rootogram, panel.rootogram, prepanel.rootogram)
export(ecdfplot, panel.ecdfplot, prepanel.ecdfplot)
export(mapplot, panel.mapplot, prepanel.mapplot)
export(segplot, prepanel.segplot, panel.segplot)

S3method(rootogram, formula)
S3method(ecdfplot, formula)
S3method(ecdfplot, numeric)
S3method(segplot, formula)

S3method(mapplot, formula)

S3method(xyplot, stl)


export(panel.3dbars, panel.3dpolygon, panel.3dtext)
export(useOuterStrips, resizePanels, combineLimits)
export(custom.theme)
export(custom.theme.2)

export(xscale.components.logpower)
export(yscale.components.logpower)
export(xscale.components.fractions)
export(yscale.components.fractions)
export(xscale.components.log10ticks)
export(yscale.components.log10ticks)
export(xscale.components.log)
export(yscale.components.log)
export(xscale.components.log10.3)
export(yscale.components.log10.3)
export(xscale.components.subticks)
export(yscale.components.subticks)

## contributions from Felix Andrews

export(mergedTrellisLegendGrob)
export(panel.key)

export(horizonplot)
S3method(horizonplot, default)
export(panel.horizonplot, prepanel.horizonplot)

export(panel.smoother)
export(panel.quantile)
export(panel.tskernel)
export(simpleSmoothTs)
S3method(simpleSmoothTs, default)
S3method(simpleSmoothTs, zoo)

export(panel.2dsmoother)

export(tileplot, panel.voronoi, panel.levelplot.points)

export(panel.xblocks)
S3method(panel.xblocks, default)
S3method(panel.xblocks, ts)
S3method(panel.xblocks, zoo)
export(panel.xyarea)
S3method(panel.xyarea, default)
S3method(panel.xyarea, ts)
S3method(panel.xyarea, zoo)
export(panel.qqmath.xyarea)

export(panel.qqmath.tails) ## Deprecated as of lattice 0.18-4

export(panel.lmlineq, panel.ablineq)
export(panel.scaleArrow)

export(marginal.plot)
S3method(c, trellis)
export(xyplot.list) ## Note: not just an S3 method

export(layer, layer_, glayer, glayer_)
export(drawLayer, flattenPanel)
S3method("+", trellis)
S3method("[", layer)
S3method(print, layer)

export(as.layer)
S3method(as.layer, layer)
S3method(as.layer, trellis)
export(doubleYScale)

export(ggplot2like)
export(ggplot2like.opts)
export(axis.grid)

export(theEconomist.theme)
export(theEconomist.opts)
export(theEconomist.axis)
export(asTheEconomist)


export(panel.ellipse)
export(panel.xyimage)


### Local variables:
### mode: R
### End:
