# latticeExtra

This package extends the functionality of the
[lattice](https://github.com/deepayan/lattice) package by providing
several new high-level functions and methods, as well as additional
utilities such as panel and axis annotation functions.

It also implements a layering mechanism similar to ggplot2, and allows
trellis plots to be combined easily using `c()`.





